==> zio-aws-rds_2.12-5.17.155.2-sources.jar: zio/aws/rds/model/ModifyDbSnapshotRequest.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyDbSnapshotRequest(
    dbSnapshotIdentifier: String,
    engineVersion: scala.Option[String] = None,
    optionGroupName: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest = {
    import ModifyDbSnapshotRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
      .builder()
      .dbSnapshotIdentifier(dbSnapshotIdentifier: java.lang.String)
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(optionGroupName.map(value => value: java.lang.String))(
        _.optionGroupName
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ModifyDbSnapshotRequest.ReadOnly =
    zio.aws.rds.model.ModifyDbSnapshotRequest.wrap(buildAwsValue())
}
object ModifyDbSnapshotRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ModifyDbSnapshotRequest =
      zio.aws.rds.model.ModifyDbSnapshotRequest(
        dbSnapshotIdentifier,
        engineVersion.map(value => value),
        optionGroupName.map(value => value)
      )
    def dbSnapshotIdentifier: String
    def engineVersion: scala.Option[String]
    def optionGroupName: scala.Option[String]
    def getDbSnapshotIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbSnapshotIdentifier)
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getOptionGroupName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("optionGroupName", optionGroupName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
  ) extends zio.aws.rds.model.ModifyDbSnapshotRequest.ReadOnly {
    override val dbSnapshotIdentifier: String =
      impl.dbSnapshotIdentifier(): String
    override val engineVersion: scala.Option[String] =
      scala.Option(impl.engineVersion()).map(value => value: String)
    override val optionGroupName: scala.Option[String] =
      scala.Option(impl.optionGroupName()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
  ): zio.aws.rds.model.ModifyDbSnapshotRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_2.13-5.17.184.1-sources.jar: zio/aws/rds/model/ModifyDbSnapshotRequest.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyDbSnapshotRequest(
    dbSnapshotIdentifier: String,
    engineVersion: Optional[String] = Optional.Absent,
    optionGroupName: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest = {
    import ModifyDbSnapshotRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
      .builder()
      .dbSnapshotIdentifier(dbSnapshotIdentifier: java.lang.String)
      .optionallyWith(engineVersion.map(value => value: java.lang.String))(
        _.engineVersion
      )
      .optionallyWith(optionGroupName.map(value => value: java.lang.String))(
        _.optionGroupName
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.ModifyDbSnapshotRequest.ReadOnly =
    zio.aws.rds.model.ModifyDbSnapshotRequest.wrap(buildAwsValue())
}
object ModifyDbSnapshotRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.ModifyDbSnapshotRequest =
      zio.aws.rds.model.ModifyDbSnapshotRequest(
        dbSnapshotIdentifier,
        engineVersion.map(value => value),
        optionGroupName.map(value => value)
      )
    def dbSnapshotIdentifier: String
    def engineVersion: Optional[String]
    def optionGroupName: Optional[String]
    def getDbSnapshotIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbSnapshotIdentifier)
    def getEngineVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("engineVersion", engineVersion)
    def getOptionGroupName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("optionGroupName", optionGroupName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
  ) extends zio.aws.rds.model.ModifyDbSnapshotRequest.ReadOnly {
    override val dbSnapshotIdentifier: String =
      impl.dbSnapshotIdentifier(): String
    override val engineVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.engineVersion())
      .map(value => value: String)
    override val optionGroupName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.optionGroupName())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.ModifyDbSnapshotRequest
  ): zio.aws.rds.model.ModifyDbSnapshotRequest.ReadOnly = new Wrapper(impl)
}
